==> piwik-0.4.3.tbz: www/piwik/core/DataTable/Filter/Pattern.php <==
<?php
/**
 * Piwik - Open source web analytics
 * 
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
 * @version $Id: Pattern.php 1377 2009-08-08 21:19:47Z vipsoft $
 * 
 * @package Piwik_DataTable
 */

/**
 * Delete all rows for which the given $columnToFilter do not contain the $patternToSearch
 * This filter is to be used on columns containing strings. 
 * Exemple: fron the keyword report, keep only the rows for which the label contains "piwik"
 * 
 * @package Piwik_DataTable
 * @subpackage Piwik_DataTable_Filter 
 */
class Piwik_DataTable_Filter_Pattern extends Piwik_DataTable_Filter
{
	private $columnToFilter;
	private $patternToSearch;
	private $patternToSearchQuoted;
	
	public function __construct( $table, $columnToFilter, $patternToSearch )
	{
		parent::__construct($table);
		$this->patternToSearch = $patternToSearch;
		$this->patternToSearchQuoted = self::getPatternQuoted($patternToSearch);
		$this->columnToFilter = $columnToFilter;
		$this->filter();
	}
	
	static public function getPatternQuoted( $pattern )
	{
		return '/'. str_replace('/', '\/', $pattern) .'/';
	}
	
	/*
	 * Performs case insensitive match
	 */
	static public function match($pattern, $patternQuoted, $string)
	{
		return @preg_match($patternQuoted . "i",  $string) == 1;
	}
	
	protected function filter()
	{
		foreach($this->table->getRows() as $key => $row)
		{
			//instead search must handle
			// - negative search with -piwik
			// - exact match with ""
			// see (?!pattern) 	A subexpression that performs a negative lookahead search, which matches the search string at any point where a string not matching pattern begins. 
			if( !self::match($this->patternToSearch, $this->patternToSearchQuoted, $row->getColumn($this->columnToFilter)))
			{
				$this->table->deleteRow($key);
			}
		}
	}
}

==> piwik-0.5.4.tbz: www/piwik/core/DataTable/Filter/Pattern.php <==
<?php
/**
 * Piwik - Open source web analytics
 * 
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
 * @version $Id: Pattern.php 1420 2009-08-22 13:23:16Z vipsoft $
 * 
 * @category Piwik
 * @package Piwik
 */

/**
 * Delete all rows for which the given $columnToFilter do not contain the $patternToSearch
 * This filter is to be used on columns containing strings. 
 * Exemple: fron the keyword report, keep only the rows for which the label contains "piwik"
 * 
 * @package Piwik
 * @subpackage Piwik_DataTable
 */
class Piwik_DataTable_Filter_Pattern extends Piwik_DataTable_Filter
{
	private $columnToFilter;
	private $patternToSearch;
	private $patternToSearchQuoted;
	
	public function __construct( $table, $columnToFilter, $patternToSearch )
	{
		parent::__construct($table);
		$this->patternToSearch = $patternToSearch;
		$this->patternToSearchQuoted = self::getPatternQuoted($patternToSearch);
		$this->columnToFilter = $columnToFilter;
		$this->filter();
	}
	
	static public function getPatternQuoted( $pattern )
	{
		return '/'. str_replace('/', '\/', $pattern) .'/';
	}
	
	/*
	 * Performs case insensitive match
	 */
	static public function match($pattern, $patternQuoted, $string)
	{
		return @preg_match($patternQuoted . "i",  $string) == 1;
	}
	
	protected function filter()
	{
		foreach($this->table->getRows() as $key => $row)
		{
			//instead search must handle
			// - negative search with -piwik
			// - exact match with ""
			// see (?!pattern) 	A subexpression that performs a negative lookahead search, which matches the search string at any point where a string not matching pattern begins. 
			if( !self::match($this->patternToSearch, $this->patternToSearchQuoted, $row->getColumn($this->columnToFilter)))
			{
				$this->table->deleteRow($key);
			}
		}
	}
}
